.. include:: /extras.rst.txt
.. highlight:: rst
.. index:: discussion-index ; Index


.. _discussion-index:

==========
Discussion
==========


.. toctree::
   :hidden:
   :titlesonly:

   why-ckeditor.rst
